#
# spec file for package scintilla
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define tar_ver 354
%define so_ver 3.0

Name:           scintilla
Summary:        A free source code editing component
Version:        3.5.4
Release:        5.16
Group:          Development/Libraries/C and C++
License:        MIT
Url:            http://www.scintilla.org
Source:         http://sourceforge.net/projects/scintilla/files/scintilla/%{version}/%{name}%{tar_ver}.tgz
Patch0:         %{name}-shared.patch
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  gcc-c++ 
BuildRequires:  glib2-devel
%if 0%{?suse_version} >= 1310
BuildRequires:  gtk3-devel
%else
BuildRequires:  gtk2-devel
%endif
BuildRequires:  libtool
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif

%description
Scintilla is a free source code editing component. It comes with
complete source code and a license that permits use in any free project
or commercial product.

As well as features found in standard text editing components,
Scintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%package -n libscintilla3
License:        MIT
Summary:        A free source code editing component
Group:          Development/Libraries/C and C++

%description -n libscintilla3
Scintilla is a free source code editing component. It comes with
complete source code and a license that permits use in any free project
or commercial product.

As well as features found in standard text editing components,
Scintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%package -n libscintilla-devel
License:        MIT
Group:          Development/Libraries/C and C++
Requires:       libscintilla3 = %{version}
Summary:        A free source code editing component

%description -n libscintilla-devel
Scintilla is a free source code editing component. It comes with
complete source code and a license that permits use in any free project
or commercial product.

As well as features found in standard text editing components,
Scintilla includes features especially useful when editing and
debugging source code. These include support for syntax styling, error
indicators, code completion and call tips. The selection margin can
contain markers like those used in debuggers to indicate breakpoints
and the current line. Styling choices are more open than with many
editors, allowing the use of proportional fonts, bold and italics,
multiple foreground and background colours and multiple fonts.

%prep
%setup -n %{name}
rm -f gtk/makefile.orig
%patch0
find . -name 'CVS' -type d -exec rm -rf \{\} \; 2> /dev/null || :

%build
cd gtk
%if 0%{?suse_version} >= 1310
make GTK3=1 %{?_smp_mflags} LIBDIR=%{_libdir} -I%{_includedir}/glib-2.0 VERSION=`echo %{so_ver} | sed 's|\.0*|:|'`
%else
make %{?_smp_mflags} LIBDIR=%{_libdir} -I%{_includedir}/glib-2.0 VERSION=`echo %{so_ver} | sed 's|\.0*|:|'`
%endif

%install
mkdir -p %{buildroot}%{_includedir}/%{name}/src
mkdir -p %{buildroot}%{_libdir}
cp include/* %{buildroot}%{_includedir}/%{name}
cp src/*.h %{buildroot}%{_includedir}/%{name}/src
mkdir -p lib
libtool --mode=install install bin/libscintilla.la `pwd`/lib
install lib/*.so* %{buildroot}%{_libdir}
mkdir -p %{buildroot}/%{_defaultdocdir}
mv doc %{buildroot}/%{_defaultdocdir}/%{name}
cp License.txt %{buildroot}/%{_defaultdocdir}/%{name}
rmdir %{buildroot}%{_includedir}/%{name}/src || :
%if 0%{?suse_version}
%fdupes -s %{buildroot}/%{_defaultdocdir}/%{name}
%endif
find %{buildroot}

%post -n libscintilla3 -p /sbin/ldconfig

%postun -n libscintilla3 -p /sbin/ldconfig

%files -n libscintilla3
%defattr(-,root,root)
%{_libdir}/*.so.*
%dir %{_defaultdocdir}/%{name}
%{_defaultdocdir}/%{name}/License.txt

%files -n libscintilla-devel
%defattr(-,root,root)
%{_libdir}/*.so
%dir %{_defaultdocdir}/%{name}
%{_defaultdocdir}/%{name}/*
%exclude %{_defaultdocdir}/%{name}/License.txt
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*

%changelog
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 3.5.4
  * No changelog available
- Build with gtk3 support for openSUSE > 13.1
- Bump so version to 3
- Add glib2-devel require; new upstream dependency
- Update scintilla-shared.patch
- Remove redundant %%clean section
- Enable parallel building with %%{?_smp_mflags}
* Mon Mar 26 2012 cfarrell@suse.com
- license update: MIT
  License is closely related to the MIT license. Use SPDX format
* Sun Nov 27 2011 coolo@suse.com
- add libtool as buildrequire to avoid implicit dependency
* Mon Oct 17 2011 mhrusecky@suse.cz
- updated to the version 2.29
* Wed Nov 11 2009 mhrusecky@suse.cz
- making sure that no include can be included twice
* Tue Nov 10 2009 mhrusecky@suse.cz
- commenting out fdupes on non-SuSE distro
* Fri Oct 30 2009 mhrusecky@suse.cz
- packaging even src headers (MySQL Workbench need them)
* Fri Oct 30 2009 mhrusecky@suse.cz
- moving headers to the scintilla directory
* Sun Oct 25 2009 mhrusecky@suse.cz
- updated to version 2.01
  - 2.01 changes
  - Fix to positioning rectangular paste when viewing line ends.
  - Don't insert new lines and indentation for line ends at end of
    rectangular paste.
  - When not in additional selection typing mode, cutting a
    rectangular selection removes all of the selected text.
  - Rectangular selections are copied to the clipboard in document
    order, not in the order of selection.
  - SCI_SETCURRENTPOS and SCI_SETANCHOR work in rectangular mode.
  - On GTK+, drag and drop to a later position in the document now
    drops at the position.
  - Fix bug where missing property did not use default value.
  - 2.0 changes
  - Multiple pieces of text can be selected simultaneously by holding
    control whil dragging the mouse. Typing, backspace and delete may
    affect all selections together.
  - Virtual space allows selecting beyond the last character on a line.
  - SciTE on GTK+ path bar is now optional and defaults to off.
  - MagikSF lexer recognises numbers correctly.
  - Folding of Python comments and blank lines improved. Bug #210240.
  - Bug fixed where background colour of last character in document
    leaked past that character.
  - Crash fixed when adding marker beyond last line in document.
    Bug #2830307.
  - Resource leak fixed in SciTE for Windows when printing fails.
    Bug #2816524.
  - Bug fixed on Windows where the system caret was destroyed during
    destruction when another window was using the system caret.
    Bug #2830223.
  - Bug fixed where indentation guides were drawn over text when the
    indentation used a style with a different space width to the
    default style.
  - SciTE bug fixed where box comment added a bare line feed rather
    than the chosen line end. Bug #2818104.
  - Reverted fix that led to wrapping whole document when displaying
    the first line of the document.
  - Export to LaTeX in SciTE fixed to work in more cases and not use
    as much space. Bug #1286548.
  - Bug fixed where EN_CHANGE notification was sent when performing a
    paste operation in a read-only document. Bug #2825485.
  - Refactored code so that Scintilla exposes less of its internal
    implementation and uses the C++ standard library for some basic
    collections. Projects that linked to Scintilla's SString or PropSet
    classes should copy this code from a previous version of Scintilla
    or from SciTE.
* Tue Jul 28 2009 mhrusecky@suse.cz
- updated to version 1.79
  - Scintilla reports memory exhaustion instead of crashing.
  - for more details see http://www.scintilla.org/ScintillaHistory.html
* Tue Jun  2 2009 mhrusecky@suse.cz
- updated to version 1.78
  - allows annotation lines to be displayed beneath each document line and to
    display a margin with different text for each document line
  - for more details see http://www.scintilla.org/ScintillaHistory.html
- not packaging static libraries anymore
* Tue Feb 17 2009 mhrusecky@suse.cz
- forgotten macro expanded - fixed -devel dependencies
* Fri Dec 19 2008 mhrusecky@suse.cz
- New Package (Version 1.77)
